# T1127 - Trusted Developer Utilities Proxy Execution

## Hunt Tags

**ID:** T1127-WIN-001

**Last Modified:** 09/09/2020 10:00

**Author:** [FalconForce](https://falconforce.nl/)

**License:** [BSD 3-Clause License](https://github.com/FalconForceTeam/FalconFriday/blob/master/LICENSE)

**References:** [Link to medium post](https://medium.com/falconforce/falconfriday-detecting-certutil-and-suspicious-code-compilation-0xff02-cfe8fb5e159e?source=friends_link&sk=3c63b684a2f6a203d8627554cec9a628)

## ATT&CK Tags

**Tactic:** Defense Evasion

**Technique:** Trusted Developer Utilities Proxy Execution (T1127)
​
## Technical description of the attack
​
In order to evade detection an attacker may bring its own code and compile it on the target machine. By default there are several binaries available on a Windows machine to utilize.

## Permission required to execute the technique

User

## Detection description

This detection looks at process executions, in some cases with specific commandline attributes to filter a lot of common noise.

## Utilized Data Source

| Event ID | Event Name | Log Provider | ATT&CK Data Source |
|---------|---------|----------|---------|
| - | DeviceProcessEvents | MDE | Process Monitoring |
​
## Hunt details

### KQL

**FP Rate:** *Low*

**Source:** *MDE*

**Description:** *This detection looks at process executions, in some cases with specific commandline attributes to filter a lot of common noise.*

**Query:**

```C#
// set timeframe
let Timeframe = 30d;
DeviceProcessEvents
| where Timestamp > ago(Timeframe)
| where (FileName has_any ("msbuild.exe", "msxsl.exe")
or (FileName has_any ("vbc.exe","csc.exe","jsc.exe") and ProcessCommandLine has_any ("/exe","/dll","/pe64","-exe","-dll","-pe64"))
or (FileName == ("ilsasm.exe") and ProcessCommandLine has_any ("out","target","t:","reference","r:")))
// Filter initations by Visual Studio since this is expected behavior
  and not(FolderPath startswith "C:\\Program Files (x86)\\Microsoft Visual Studio" 
  or InitiatingProcessFolderPath startswith "C:\\Program Files (x86)\\Microsoft Visual Studio" 
  and (InitiatingProcessFileName == "devenv.exe" or InitiatingProcessFileName == "WDExpress.exe"))
```

## Considerations

## False Positives

In some environments there might be some legitimate use, in general this is expected to be only on developer machines

## Detection Blind Spots

* In case of heavy commandline obfuscation it might be missed

## References

* https://blog.f-secure.com/hunting-for-silenttrinity/
* https://blog.talosintelligence.com/2019/11/hunting-for-lolbins.html
* https://lolbas-project.github.io/lolbas/Binaries/Msbuild/
* https://lolbas-project.github.io/lolbas/Binaries/Csc/
* https://lolbas-project.github.io/lolbas/Binaries/Ilasm/
* https://lolbas-project.github.io/lolbas/Binaries/Jsc/
* https://lolbas-project.github.io/lolbas/Binaries/Vbc/
