# T1218.002 - Suspicious .CPL files

## Hunt Tags

**ID:** T1218-WIN-001

**Last Modified:** 25/09/2020 

**Author:** [FalconForce](https://falconforce.nl/)

**License:** [BSD 3-Clause License](https://github.com/FalconForceTeam/FalconFriday/blob/master/LICENSE)

**References:** [Link to medium post](https://medium.com/falconforce/falconfriday-process-injection-and-malicious-cpl-files-0xff03-8ba1ee5da64?source=friends_link&sk=1ed3672c2e7961dac11c1472cb5757e8)

## ATT&CK Tags

**Tactic:** Privilege Escalation

**Technique:** Signed Binary Proxy Execution: Control Panel (T1218.002)
​

## Technical description of the attack
​
CPL files are a special kind of DLLs which have a special meaning in Windows. When Windows sees a CPL file, it assumes it's a control panel item and proceeds to execute it as such. Attackers use CPL files as a way to evade detection. If the detection rules are aimed at detecting .DLL and .EXE files, a CPL might go unnoticed. 

## Permission required to execute the technique

User

## Detection description

This detection is aimed at identifying ImageLoad events of .CPL which have a "low reputation". We first compile a list of all distinct hashes of .CPL files loaded. For each file, we check the Microsoft Threat Intel database to understand how often it has been seen before by Microsoft. We set some tresholds for signed and unsigned CPLs. If the file is below the treshold (i.e. 50 and resp. 100 in this case), an alert is triggered.  

## Utilized Data Source
| Event ID | Event Name | Log Provider | ATT&CK Data Source |
|---------|---------|----------|---------|
| - | DeviceImageLoadEvents | MDE | API monitoring |
| - | FileProfile | MDE | -  |
​
## Hunt details

### KQL
**FP Rate:** *Low*

**Source:** *MDE*

**Description:** *See above*

**Query:**

```C#
//Fairly accurate. Depends on ATP for "Global Prevalence" to filter out false positives.
let suspiciousCPLs = DeviceImageLoadEvents
| where FileName endswith ".cpl"
| summarize by SHA1
| invoke FileProfile(SHA1, 1000)
| where ((isempty(Signer) or not(IsCertificateValid)) and GlobalPrevalence < 100) or GlobalPrevalence < 50;
DeviceImageLoadEvents
| where SHA1 has_any (suspiciousCPLs) and ActionType == "ImageLoaded"
```

## Considerations

* The thresholds require fine-tuning for your environment. Lower is better, but needs to be balanced with the false positive rate. Set the values as low as possible, where the false positive rate is still acceptable for you. 
* Should a valid signature be a reason to have a lower threshold for your environment? 
* The timeframe should be sufficiently short to ensure that the number of unique CPL hashes is < 1000, because of the limitations in the FileProfile function.

## False Positives

* Some software add legit CPL files. If the software is obscure enough, global prevalence might be very low while still being legit. (e.g. some kind of industrial control system ;-))
* 

## Detection Blind Spots

* An attacker can use any other extension to bypass this detection. Although this takes away the ability of "double clicking" a CPL file, the concept still works. 

## References

* https://www.ired.team/offensive-security/code-execution/executing-code-in-control-panel-item-through-an-exported-cplapplet-function
* https://docs.microsoft.com/en-us/windows/win32/shell/using-cplapplet
* https://www.ired.team/offensive-security/code-execution/code-execution-through-control-panel-add-ins
* https://attack.mitre.org/techniques/T1218/011/
* https://attack.mitre.org/techniques/T1218/002/
