# T1059.001 - PowerShell - System.Management.Automation

## Hunt Tags

**ID:** T1059.001-WIN-001

**Last Modified:** 12/08/2020

**Author:** [FalconForce](https://falconforce.nl/)

**License:** [BSD 3-Clause License](https://github.com/FalconForceTeam/FalconFriday/blob/master/LICENSE)

**References:** [Link to medium post](https://medium.com/@0xffhh/1f972d65ce1b?source=friends_link&sk=e48d9cb974e216cc4b9b61945a3b177d)

## ATT&CK Tags

**Tactic:** Execution

**Technique:** Command and Scripting Interpreter (T1059)
​

## Technical description of the attack

An attacker uses the System.Management.Automation DLL to execute powershell commands, instead of the PowerShell.exe

## Permission required to execute the technique

User

## Detection description

The rule identifies all processes that load the System.Management.Automation.dll and excludes some known processes that do so. 

## Utilized Data Source
| Event ID | Event Name | Log Provider | ATT&CK Data Source |
|---------|---------|----------|---------|
| - | DeviceImageLoadEvents | MDE | Loaded DLLs |
| 7 | Image Load            | Sysmon | Loaded DLLs |

## Hunt details

### KQL
**FP Rate:** *Medium*

**Source:** *MDE*

**Description:** *Show all executables that load the System.Management.Automation(.ni).dll and exclude powershell.exe and other known binaries that do so.*

**Query:**

```C# 
DeviceImageLoadEvents
| where FileName =~ "System.Management.Automation.dll" or FileName =~ "System.Management.Automation.ni.dll"
| where InitiatingProcessFolderPath !~ "C:\\Windows\\System32\\WindowsPowerShell\\v1.0" and InitiatingProcessFolderPath !~ "C:\\Windows\\SysWOW64\\WindowsPowerShell\\v1.0"  and (InitiatingProcessFileName !~ "powershell.exe" or InitiatingProcessFileName !~ "powershell_ise.exe")
// The RemoteFXvGPUDisablement.exe is for GPU virtualization, MS recommends to remove this service as of July 2020. 
| where InitiatingProcessFolderPath !~ "C:\\Windows\\system32" and InitiatingProcessFileName !~ "RemoteFXvGPUDisablement.exe"
// exclusions below can be enabled if you're using visual studio 
//| where InitiatingProcessFolderPath !contains "C:\\Windows\\Microsoft.NET\\Framework" and InitiatingProcessFileName !~ "devenv.exe"
//| where InitiatingProcessFolderPath !contains "\\Microsoft Visual Studio\\2019\\Community\\Common7\\ServiceHub\\Hosts\\ServiceHub.Host.CLR.x86" and InitiatingProcessFileName !startswith "servicehub"
//| where InitiatingProcessFolderPath !contains "\\Microsoft Visual Studio\\2019\\Community\\Common7\\IDE" and InitiatingProcessFileName !~ "mscorsvw.exe" and InitiatingProcessParentFileName !~ "ngen.exe"
| project Timestamp,DeviceName,InitiatingProcessAccountName,ActionType,InitiatingProcessFileName,InitiatingProcessCommandLine,InitiatingProcessIntegrityLevel,FileName,InitiatingProcessParentId,InitiatingProcessId
```

### SPL

**FP Rate:** *Medium*

**Source:** Sysmon

**Description:** *Show all executables that load the System.Management.Automation(.ni).dll and exclude powershell.exe and other known binaries that do so.*

**Query:**

```c#
index=windows (source="XmlWinEventLog:Microsoft-Windows-Sysmon/Operational" OR source="WinEventLog:Microsoft-Windows-Sysmon/Operational") EventCode=7 (ImageLoaded="*\\System.Management.Automation.ni.dll" OR ImageLoaded="*\\System.Management.Automation.dll") NOT(Image="C:\\Windows\\*\\WindowsPowerShell\\v1.0\\powershell.exe" OR Image="C:\\Windows\\*\\WindowsPowerShell\\v1.0\\\\powershell_ise.exe") Image!="C:\\Windows\\system32\\*" 
| table _time EventDescription Computer Image ImageLoaded Signed Signature SignatureStatus ProcessId ProcessGuid
```



## Considerations

- If the query provides too many false positives, you can consider to filter out all binaries signed by Microsoft.
- If the query still provides too many false positives, you can consider to filter out all signed binaries.
- There is a trade-off in using the !contains operator for InitiatingProcessFolderPath. An attacker who knows these rules can abuse these pathnames to stay undetected. You might want to include the full path and match on that if you're more paranoid than average. Full paths are slightly harder to bypass since in most cases you need local admin to write to the full path locations.  

## False Positives
- Visual Studio 2019 (see exclusion in query)

## Detection Blind Spots
- Applications that load this DLL from an embedded memory block will not show up. Since the DLL lives in memory as a byte array and doesn't have this name, it's invisible. An example is [UnmanagedPowershell](https://github.com/leechristensen/UnmanagedPowerShell/blob/master/UnmanagedPowerShell/UnmanagedPowerShell.cpp). On line 228 here, you can see that the unmanaged C++ code calls the managed Load_3 function on the AppDomain object, where the DLL is loaded from a memory block. 

## References

* https://attack.mitre.org/techniques/T1059/001/
* https://www.ired.team/offensive-security/code-execution/powershell-without-powershell
* https://github.com/leechristensen/UnmanagedPowerShell