# T1490 - Inhibit system recovery
## Hunt Tags
**ID:** T1490

**Last Modified:** 06/08/2021

**Author:** [FalconForce](https://falconforce.nl/)

**License:** [BSD 3-Clause License](https://github.com/FalconForceTeam/FalconFriday/blob/master/LICENSE)

**References:** [Link to medium post](https://medium.com/falconforce/falconfriday-detecting-important-data-destruction-by-ransomware-0xff15-75f76ed4a4cd?source=friends_link&sk=31f77860d33e1bbab09bafd7090a5fc2)

## ATT&CK Tags
**Tactic:** Impact

**Technique:** Inhibit system recovery

## Technical description of the attack
Attackers often delete backups prior to deploying ransomware in order to maximize their chances of getting the ransom paid. Since the organization doesn't have any backups anymore, it's significantly more likely that they will pay in order to retrieve their files. 
This is a classic definition of this technique "Inhibit system recovery". 
 

## Permission required to execute the technique
Administrator

## Detection description
There are various techniques which can be used to make deletion of backups harder. In Azure, you can enable a "cannot-delete" lock on a resource, enable versioning for files/blob storage and enable soft deletes. The most rigorous method is to use "immutable blobs".
Similar features are available in the "Azure Backups" service offered by Azure, even though "Azure Backups" for now doesn't support "immutable storage". 
This collection of rules attempts to detect tampering with the settings of a backup storage account / Azure Backup vault. Any changes in the settings regarding versioning, soft-delete or "cannot-delete lock" will be detected by these rules. There are some
caveats for detecting changes in "soft-delete" and "versioning". Please refer to the blog post for all details. 
Even if you're using immutable storage, these queries provide you with warnings that someone is *trying* to mess around with your settings. 

## Utilized Data Source
| Event ID | Event Name | Log Provider | ATT&CK Data Source |
|---------|---------|----------|---------|
| - | AzureActivity | Azure |  |
| - | StorageFileLogs | Azure Diagnostics |  |
| - | StorageBlobLogs | Azure Diagnostics |  |


## Hunt details
### KQL

**FP Rate:** *Low*

**Source:** *AzureDiagnostics*, *AzureActivity*

**Description:** *See above*

**Query:**

Modify soft delete settings for Azure Backup:
```C#
AzureActivity
| where OperationName =~ "Update Resource Config"
| where Resource =~ "vaultconfig" and ResourceGroup == "<YOUR RG NAME HERE>"
| where ActivityStatus != "Started" //Leave out the started. Success/Failed 
```

Delete a lock (i.e. cannot-delete lock) on a resource:
```C#
AzureActivity
| where OperationNameValue =~ "Microsoft.Authorization/locks/delete" 
| where Resource =~ "<YOUR LOCK NAME HERE>"
| where ActivityStatus != "Started" // leave out the start. We want to get one hit only for the final result being "Succeeded" or "Failed" or whatever else. 
```

Delete a "protected server" from Azure Backups:
```C#
AzureActivity
| where OperationName =~ "Unregister Service Container" 
| where ActivityStatus != "Started" // leave out the start. We want to get one hit only for the final result being "Succeeded" or "Failed" or whatever else. 
```

Modify soft delete / versioning settings for Containers and File Shares:
```C#
AzureActivity
// make sure to do the regex case insensitive, as the casing for the operation is different :( 
// also make sure to test this rule on a regular basis to ensure it keeps working even if Microsoft at some
// point decided to change the name of the operation. 
| where OperationName matches regex "(?i)Put ((file)|(blob)) service properties" 
| where ResourceGroup =~ "<YOUR RG NAME HERE>"
| where ActivityStatus != "Started" // leave out the start. We want to get one hit only for the final result being "Succeeded" or "Failed" or whatever else. 
```

Delete a fileshare:
```C#
StorageFileLogs
| where OperationName =~ "DeleteShare"
| parse _ResourceId with * "/subscriptions/" Subscription "/resourcegroups/" ResourceGroup "/providers/" Provider "/storageaccounts/" StorageAccountName "/" *
| where StorageAccountName =~ "<YOUR STORAGE ACCOUNT NAME HERE>" 
```

Delete a container:
```C#
StorageBlobLogs
| where OperationName =~ "DeleteContainer"
| parse _ResourceId with * "/subscriptions/" Subscription "/resourcegroups/" ResourceGroup "/providers/" Provider "/storageaccounts/" StorageAccountName "/" *
| where StorageAccountName =~ "<YOUR STORAGE ACCOUNT NAME HERE>" 
```

Delete a file from a fileshare:
```C#
StorageFileLogs
| where OperationName =~ "DeleteFile"
| parse _ResourceId with * "/subscriptions/" Subscription "/resourcegroups/" ResourceGroup "/providers/" Provider "/storageaccounts/" StorageAccountName "/" *
| where StorageAccountName =~ "<YOUR STORAGE ACCOUNT NAME HERE>" 
```

Delete a file from a Blob:
```C#
StorageBlobLogs
| where OperationName =~ "DeleteBlob"
| parse _ResourceId with * "/subscriptions/" Subscription "/resourcegroups/" ResourceGroup "/providers/" Provider "/storageaccounts/" StorageAccountName "/" *
| where StorageAccountName =~ "<YOUR STORAGE ACCOUNT NAME HERE>" 
```

## Considerations
* Some of the queries require you to enable additional diagnostic logging on the storage account and storage service type. Refer to the blogpost. 

## False Positives
*  
  
## Detection Blind Spots
*  When settings regarding soft-delete / versioning are changed, you can't see it. The logging only says that "some settings" have changed, not which one. You need to manually verify the settings. 

## References
* 


