# T1566.002 - Phishing: Spearphishing link
## Hunt Tags
**ID:** T1566.002

**Last Modified:** 18/12/2020

**Author:** [FalconForce](https://falconforce.nl/)

**License:** [BSD 3-Clause License](https://github.com/FalconForceTeam/FalconFriday/blob/master/LICENSE)

**References:** [Link to medium post](https://medium.com/falconforce/falconfriday-catching-more-macros-0xff0a-ec8273ab115a?source=friends_link&sk=90696a8b7003c5c71f5b2c91575281c0)

## ATT&CK Tags
**Tactic:** Initial Access

**Technique:** Phishing: Spearphishing Link

## Technical description of the attack
The attacker sends a spearphishing email to a user. The email contains a link, which points to a website that eventually presents the user a download of an MS Office document. This document contains a malicious macro and provides initial access to the user's machine. 

## Permission required to execute the technique
User

## Detection description
The query looks for office applications which spawn a child process and have a browser as the parent of that office application. 

## Utilized Data Source
| Event ID | Event Name | Log Provider | ATT&CK Data Source |
|---------|---------|----------|---------|
| - | DeviceProcessEvents | MDE | Process monitoring |


## Hunt details
### KQL

**FP Rate:** *Medium*

**Source:** *MDE*

**Description:** *See above*

**Query:**

```C#
let browsers = dynamic(["iexplore.exe", "chrome.exe", "firefox.exe", "msedge.exe"]); //customize this list for your environment
let officeApps = dynamic(["winword.exe", "excel.exe", "powerpnt.exe"]); //consider adding other office applications such as publisher, visio and access. 
//this is a whitelist of the most common child processes. This is a quick and dirty solution. Consider whitelisting the full process path instead of filename
//also make this list as short as possible. Remove anything from this list if it doesn't occur in your organization. 
let whitelist = dynamic(["MSOSYNC.exe", "splwow64.exe", "csc.exe", "outlook.exe", "AcroRd32.exe", "Acrobat.exe", "explorer.exe", "DW20.exe", 
"Microsoft.Mashup.Container.Loader.exe", "Microsoft.Mashup.Container.NetFX40.exe", "WerFault.exe", "CLVIEW.exe"]); 
DeviceProcessEvents
| where InitiatingProcessParentFileName in~ (browsers) and InitiatingProcessFileName in~ (officeApps) and 
 FileName !in~ (officeApps) and FileName !in~ (browsers) //and FileName !in~ (whitelist)
| project-rename ProcessStart_Timestamp = Timestamp
```

## Considerations
* The current whitelist is quick and dirty. Use full pathnames instead of filenames for whitelisting child processes.
* You can improve this query by further filtering the results for office processes that have loaded the VBE7.dll, required for macro execution
* If you're concerned about macro executions directly from email, you can add outlook.exe as "grand parent" instead of only browsers. 
* Be careful not to whitelist LOLBINs. 

## False Positives
*  
  

## Detection Blind Spots
* Currently, the whitelist based on filenames allows an easy bypass. 

## References
*  