# T1021.001 - Remote Services: Remote Desktop Protocol - SharpRDP

## Hunt Tags

**ID:** T1021.001

**Last Modified:** 03/12/2020

**Author:** [FalconForce](https://falconforce.nl/)

**License:** [BSD 3-Clause License](https://github.com/FalconForceTeam/FalconFriday/blob/master/LICENSE)

**References:** [Link to medium post]((https://medium.com/falconforce/falconfriday-rpc-service-creation-sharprdp-0xff08-8bf15744ca04))

## ATT&CK Tags

**Tactic:** Lateral Movement

**Technique:** Remote Services: Remote Desktop Protocol (T1021.001)

## Technical description of the attack

SharpRDP tries to remediate this by allowing attackers to perform remote command execution through RDP without the need to have real-time manual interaction by simulating keystrokes on the target system. This allows an attacker to (asynchronously) run the binary on an already compromised system, which in turn will connect to the target system and execute a set of keystrokes.

## Permission required to execute the technique

(Local) administrator on target machine

## Detection description

Monitor for the behavior that SharpRDP exhibits on the target system. The most relevant is leveraging taskmgr.exe to gain elevated execution, which means that taskmgr.exe is creating unexpected child processes.

## Utilized Data Source

| Event ID | Event Name | Log Provider | ATT&CK Data Source |
|---------|---------|----------|---------|
| - | DeviceProcessEvents | MDE | Process monitoring |
| - | DeviceLogonEvents | MDE | Authentication logs |

## Hunt details

### KQL

**FP Rate:** *Low*

**Source:** *MDE*

**Description:** *See above*

**Query:**

```C#
let executions = DeviceProcessEvents
| where InitiatingProcessFileName contains "taskmgr" and AccountName != "lapsadmin"
// Add the filter to look for stock SharpRDP behavior, however with small tweaks one of the command line examples might occur.
//| where not(InitiatingProcessCommandLine has_any ("/1","/2","/3","/4"))
| where not(FolderPath =~ @"c:\Windows\system32\WerFault.exe" and ProcessCommandLine contains "-u -p")
| where not(FolderPath =~ @"c:\windows\system32\mmc.exe" and ProcessCommandLine contains @"C:\WINDOWS\System32\services.msc")
| where not(FolderPath =~ @"c:\windows\system32\resmon.exe");
executions
| join kind=leftsemi  (DeviceLogonEvents
| where LogonType in ('Unlock', 'RemoteInteractive') and not (LogonType == 'Unlock' and RemoteIP == '127.0.0.1') and RemoteIP != "" and ActionType == "LogonSuccess") on DeviceId, LogonId
```

## Considerations

* It is fairly trivial to change the characteristics of SharpRDP, this detection covers the unaltered version.
* Improvements can be made by correlating these events with network session telemetry to find short lived sessions.

## False Positives

* Administrators can use this legitimately. However, in most environments this is still rare. 

## Detection Blind Spots

* This detection has a focus on the use of taskmgr, an attacker can make use of cmd.exe or powershell.exe directly. These processes are not elevated.

## References

* 