# T1055 - Process Injection with CreateRemoteThread

## Hunt Tags

**ID:** T1055-WIN-001

**Last Modified:** 25/09/2020 

**Author:** [FalconForce](https://falconforce.nl/)

**License:** [BSD 3-Clause License](https://github.com/FalconForceTeam/FalconFriday/blob/master/LICENSE)

**References:** [Link to medium post](https://medium.com/falconforce/falconfriday-process-injection-and-malicious-cpl-files-0xff03-8ba1ee5da64?source=friends_link&sk=1ed3672c2e7961dac11c1472cb5757e8)

## ATT&CK Tags

**Tactic:** Privilege Escalation

**Technique:** Process Injection (T1055)
​

## Technical description of the attack
​
Process injection is an overarching technique used to execute code in other processes. There are a large number of documented approaches to achieve process injection. The more classic approaches for process injection use the CreateRemoteThread API. This is also often used by attacker to migrate to different processes. Although this API is not considered to be "opsec safe", it's still very often used in attacks by malicious actors as well as some red teams (possible emulating those actors). 

## Permission required to execute the technique

User

## Detection description

This rule filters all logged uses of the "CreateRemoteThread" API where the injecting process ("injector") is not equal to the process that is injected into ("injectee"). Now we filter out unique injectors based on SHA1 hash and enrich those using the [FileProfile](https://docs.microsoft.com/en-us/microsoft-365/security/mtp/advanced-hunting-fileprofile-function?view=o365-worldwide) function in Defender for Endpoint. Finally, we summarize a list of all unique SHA1 hashes where the global prevalence is below a certain threshold (i.e. suspiciousCRTs). 

Finally, we filter all log events of CreateRemoteThread where the injector was in the previously built list (i.e. suspiciousCRTs). 

## Utilized Data Source
| Event ID | Event Name | Log Provider | ATT&CK Data Source |
|---------|---------|----------|---------|
| - | DeviceEvents | MDE | API monitoring |
| - | FileProfile | MDE | -  |
​
## Hunt details

### KQL
**FP Rate:** *Low*

**Source:** *MDE*

**Description:** *See above*

**Query:**

```C#
let suspiciousCRT = DeviceEvents
| where ActionType =~ "CreateRemoteThreadApiCall" and ProcessId != InitiatingProcessId
| summarize by InitiatingProcessSHA1
| invoke FileProfile(InitiatingProcessSHA1, 1000)
| where GlobalPrevalence < 200 or ((isempty(Signer) or not(IsCertificateValid)) and GlobalPrevalence < 500)
| summarize by InitiatingProcessSHA1;
DeviceEvents
| where ActionType =~ "CreateRemoteThreadApiCall" and ProcessId != InitiatingProcessId and InitiatingProcessSHA1 in (suspiciousCRT)
```

## Considerations

* The thresholds require fine-tuning for your environment. Lower is better, but needs to be balanced with the false positive rate. Set the values as low as possible, where the false positive rate is still acceptable for you. 
* Should a valid signature be a reason to have a lower threshold for your environment? 
* The timeframe should be sufficiently short to ensure that the number of hashes is < 1000, because of the limitations in the FileProfile function.

## False Positives

* There are legit obsucre application that use CreateRemoteThread for process injection. 

## Detection Blind Spots

* Process injections originating from legit binaries are (by design) not detected by this rule. E.g. malware running in a real svchost.exe injecting into another process is not detected, as svchost.exe is a legit binary (i.e. hash of file is observed >200 times globally). 
* Process injection techniques that use other Windows APIs, are not detected (by design).

## References

* https://www.elastic.co/blog/ten-process-injection-techniques-technical-survey-common-and-trending-process
* https://i.blackhat.com/USA-19/Thursday/us-19-Kotler-Process-Injection-Techniques-Gotta-Catch-Them-All-wp.pdf
* https://www.ired.team/offensive-security/code-injection-process-injection
* https://attack.mitre.org/techniques/T1055/
