# T1574.002 - Hijack Execution Flow: DLL Side-Loading
## Hunt Tags
**ID:** T1574.002 

**Last Modified:** 06/11/2020

**Author:** [FalconForce](https://falconforce.nl/)

**License:** [BSD 3-Clause License](https://github.com/FalconForceTeam/FalconFriday/blob/master/LICENSE)

**References:** [Link to medium post](https://medium.com/falconforce/falconfriday-dll-hijacking-suspicious-unsigned-files-0xff06-7b2c2a9dcae6?source=friends_link&sk=5807977fd38f01b5fa8e06e5c4d5b059)

## ATT&CK Tags
**Tactic:** Privilege Escalation

**Technique:** Hijack Execution Flow: DLL Side-Loading

## Technical description of the attack
In DLL hijacking, an attacker creates or overwrites a DLL with "normal" privileges which is then loaded and executed by a process with high privileges. 

## Permission required to execute the technique
User
## Detection description
We need to identify all DLLs loaded by "high integrity" processes and cross check the DLL paths against FileCreate/FileModify events of the same DLL by a medium integrity process. That's in a nutshell today's hunt. 
Of course, we need to do some magic to filter out false positives as much as possible. So any FileCreate/FileModify done by "NT Authoriy\System" and the "RID 500" users aren't interesting. Also, we only want to see the FileCreate/FileModify actions which are performed with a default or limited token elevation. If done with a full elevated token, the user is apparently admin already.

## Utilized Data Source
| Event ID | Event Name | Log Provider | ATT&CK Data Source |
|---------|---------|----------|---------|
| - | DeviceProcessEvents | MDE | Process monitoring |
| - | DeviceImageLoadEvents | MDE | Loaded DLLs |

## Hunt details
### KQL

**FP Rate:** *Medium*

**Source:** *MDE*

**Description:** *See above*

**Query:**
Approach 1:
```C#
let imls = materialize(
    DeviceImageLoadEvents
    | where InitiatingProcessIntegrityLevel in ("High", "System") and FileName !endswith ".exe"
    | project FolderPath=tolower(FolderPath), InitiatingProcessFileName, InitiatingProcessIntegrityLevel
    | distinct FolderPath, InitiatingProcessFileName, InitiatingProcessIntegrityLevel
);
imls 
| join (
    DeviceFileEvents 
    | where FolderPath in~ ((imls | project FolderPath)) and ActionType in ("FileCreated", "FileModified") and 
		InitiatingProcessIntegrityLevel !in ("High", "System", "") and InitiatingProcessAccountSid != "S-1-5-18" and 
		InitiatingProcessTokenElevation in ("TokenElevationTypeDefault", "TokenElevationTypeLimited") and InitiatingProcessAccountSid !endswith "-500"
    | extend FolderPath=tolower(FolderPath)
) on FolderPath
| project-away FolderPath1
```

## Considerations
* Each result of this query identifies a potential DLL hijacking possibility with a high precision. 
* Not every result is malicious tough. 

## False Positives
*  A lot of false positives which are not malicious (and hence FP), but are weaknesses. 
  

## Detection Blind Spots
* If the FileCreate/FileModify happens earlier than the lookback period of the query, a potential hijack will not be detected. 


## References
*  https://docs.microsoft.com/en-us/windows/security/threat-protection/auditing/event-4688
*  https://attack.mitre.org/techniques/T1574/002/
  