# T1546.015 - Component Object Model Hijacking - Vault7 trick

## Hunt Tags

**ID:** T1546.015-WIN-001

**Last Modified:** 12/08/2020

**Author:** [FalconForce](https://falconforce.nl/)
​
**License:** [BSD 3-Clause License](https://github.com/FalconForceTeam/FalconFriday/blob/master/LICENSE)

**References:** [Link to medium post](https://medium.com/@0xffhh/1f972d65ce1b?source=friends_link&sk=e48d9cb974e216cc4b9b61945a3b177d)

## ATT&CK Tags

**Tactic:** Persistence

**Technique:** Component Object Model Hijacking (T1546.015)
​

## Technical description of the attack
​
This query is aimed at detecting persistence using a specific way of COM hijacking, first published in the [Vault7 leaks](https://wikileaks.org/ciav7p1/cms/page_13763373.html). A variant is described on [ired.team](https://www.ired.team/offensive-security/code-execution/forcing-iexplore.exe-to-load-a-malicious-dll-via-com-abuse).

## Permission required to execute the technique

User

## Detection description

Look for the very specific value of "Attribute" in the "ShellFolder" CLSID of a COM object. This value (0xf090013d) seems to only link back to this specific persistence method. The blog post linked above provides more background on the meaning of this value. 

## Utilized Data Source
| Event ID | Event Name | Log Provider | ATT&CK Data Source |
|---------|---------|----------|---------|
| - | DeviceRegistryEvents | MDE | Windows Registry |

​
## Hunt details

### KQL
**FP Rate:** *Low*

**Source:** *MDE*

**Description:** *Find all registry events where the Attribute value has been set to this very specific IoC value or bigger*

**Query:**

```C#
DeviceRegistryEvents
| where RegistryKey contains "ShellFolder"  and ActionType == "RegistryValueSet" and RegistryValueName =~ "Attributes" 
//toint automatically converts base10 and base16 strings to int toint("0xFF") == toint("255") == int(0xFF) ==  int(255)
//here we need to use long type as int in KQL is a 32-bit signed integer
// We're using >= to make sure that if someone adds an additional flag to this field, it doesn't bypass this hunt.
// removing any flag will bypass this hunt, but more research is needed to understand which of the flag values are relevant
| where tolong(RegistryValueData) >= long(0xf090013d) 
```

## Considerations
- The proper way to check if this technique is used, is by using the binary_and function in KQL. This is a future improvement. 
- This COM hijack can also be used as a UAC bypass [as documented here](https://github.com/FuzzySecurity/DefCon25/blob/master/DefCon25_UAC-0day-All-Day_v1.2.pdf) and [implemented in metasploit](https://www.rapid7.com/db/modules/exploit/windows/local/bypassuac_comhijack).
- 

## False Positives
- A legit case which uses a flag that happens to be bigger in value might trigger a false positive. See *Consideration* above. The required improvement is to use the function ``binary_or`` instead of the ``>=``.

## Detection Blind Spots
- It's currently unknown which of the flags that together form this specific value of 0xf090013d are required for persistence. It's likely that there is a smaller value which still leads to persistence. More research is required to figure this out. [See blog post for full explanation](https://medium.com/@0xffhh/1f972d65ce1b?source=friends_link&sk=e48d9cb974e216cc4b9b61945a3b177d). 

## References

* https://wikileaks.org/ciav7p1/cms/page_13763373.html
* https://vanmieghem.io/persisting-like-a-cia-agent/
